# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# The requesting account failed to pass the qualification review.
ACCOUNTQUALIFICATIONRESTRICTIONS = 'AccountQualificationRestrictions'

# CVM API call failed.
CALLCVMERROR = 'CallCvmError'

# No scaling activity is generated.
FAILEDOPERATION_NOACTIVITYTOGENERATE = 'FailedOperation.NoActivityToGenerate'

# An internal error occurred.
INTERNALERROR = 'InternalError'

# The CMQ API call failed.
INTERNALERROR_CALLCMQERROR = 'InternalError.CallCmqError'

# The internal API call failed.
INTERNALERROR_CALLERROR = 'InternalError.CallError'

# CLB API call failed.
INTERNALERROR_CALLLBERROR = 'InternalError.CallLbError'

# Monitor API call failed.
INTERNALERROR_CALLMONITORERROR = 'InternalError.CallMonitorError'

# The notification service API call failed.
INTERNALERROR_CALLNOTIFICATIONERROR = 'InternalError.CallNotificationError'

# The STS API call failed.
INTERNALERROR_CALLSTSERROR = 'InternalError.CallStsError'

# The tag API call failed.
INTERNALERROR_CALLTAGERROR = 'InternalError.CallTagError'

# The TVPC API call failed.
INTERNALERROR_CALLTVPCERROR = 'InternalError.CallTvpcError'

# VPC API call failed.
INTERNALERROR_CALLVPCERROR = 'InternalError.CallVpcError'

# Exceptions occurred while invoking other services.
INTERNALERROR_CALLEEERROR = 'InternalError.CalleeError'

# An internal request error occurred.
INTERNALERROR_REQUESTERROR = 'InternalError.RequestError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Multiple parameters specified conflict and cannot co-exist.
INVALIDPARAMETER_CONFLICT = 'InvalidParameter.Conflict'

# The `hostname` parameter is unavailable to this image.
INVALIDPARAMETER_HOSTNAMEUNAVAILABLE = 'InvalidParameter.HostNameUnavailable'

# The parameter is invalid in a specific scenario.
INVALIDPARAMETER_INSCENARIO = 'InvalidParameter.InScenario'

# Invalid parameter combination.
INVALIDPARAMETER_INVALIDCOMBINATION = 'InvalidParameter.InvalidCombination'

# The specified CLB does not exist in the current scaling group.
INVALIDPARAMETER_LOADBALANCERNOTINAUTOSCALINGGROUP = 'InvalidParameter.LoadBalancerNotInAutoScalingGroup'

# A parameter is missing. One of the two parameters must be specified.
INVALIDPARAMETER_MUSTONEPARAMETER = 'InvalidParameter.MustOneParameter'

# Some parameters cannot coexist and should be deleted.
INVALIDPARAMETER_PARAMETERMUSTBEDELETED = 'InvalidParameter.ParameterMustBeDeleted'

# The two parameters specified conflict and cannot co-exist.
INVALIDPARAMETERCONFLICT = 'InvalidParameterConflict'

# Wrong parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The specified base capacity cannot exceed the max capacity.
INVALIDPARAMETERVALUE_BASECAPACITYTOOLARGE = 'InvalidParameterValue.BaseCapacityTooLarge'

# A classic CLB should be specified.
INVALIDPARAMETERVALUE_CLASSICLB = 'InvalidParameterValue.ClassicLb'

# Conflicting notification receiver type.
INVALIDPARAMETERVALUE_CONFLICTNOTIFICATIONTARGET = 'InvalidParameterValue.ConflictNotificationTarget'

# The cron expression specified for the scheduled task is invalid.
INVALIDPARAMETERVALUE_CRONEXPRESSIONILLEGAL = 'InvalidParameterValue.CronExpressionIllegal'

# Exception with CVM parameter validation.
INVALIDPARAMETERVALUE_CVMCONFIGURATIONERROR = 'InvalidParameterValue.CvmConfigurationError'

# Exception with CVM parameter validation.
INVALIDPARAMETERVALUE_CVMERROR = 'InvalidParameterValue.CvmError'

# Duplicate CLB instances
INVALIDPARAMETERVALUE_DUPLICATEDFORWARDLB = 'InvalidParameterValue.DuplicatedForwardLb'

# Duplicated subnet.
INVALIDPARAMETERVALUE_DUPLICATEDSUBNET = 'InvalidParameterValue.DuplicatedSubnet'

# The end time of the scheduled task is before the start time.
INVALIDPARAMETERVALUE_ENDTIMEBEFORESTARTTIME = 'InvalidParameterValue.EndTimeBeforeStartTime'

# Invalid filter.
INVALIDPARAMETERVALUE_FILTER = 'InvalidParameterValue.Filter'

# A CLB should be specified.
INVALIDPARAMETERVALUE_FORWARDLB = 'InvalidParameterValue.ForwardLb'

# The auto scaling group name already exists.
INVALIDPARAMETERVALUE_GROUPNAMEDUPLICATED = 'InvalidParameterValue.GroupNameDuplicated'

# Invalid hostname
INVALIDPARAMETERVALUE_HOSTNAMEILLEGAL = 'InvalidParameterValue.HostNameIllegal'

# The specified image does not exist.
INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'

# Invalid instance name
INVALIDPARAMETERVALUE_INSTANCENAMEILLEGAL = 'InvalidParameterValue.InstanceNameIllegal'

# The instance type is not supported.
INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTED = 'InvalidParameterValue.InstanceTypeNotSupported'

# Invalid scaling activity ID.
INVALIDPARAMETERVALUE_INVALIDACTIVITYID = 'InvalidParameterValue.InvalidActivityId'

# Invalid scaling group ID.
INVALIDPARAMETERVALUE_INVALIDAUTOSCALINGGROUPID = 'InvalidParameterValue.InvalidAutoScalingGroupId'

# Invalid notification ID.
INVALIDPARAMETERVALUE_INVALIDAUTOSCALINGNOTIFICATIONID = 'InvalidParameterValue.InvalidAutoScalingNotificationId'

# Invalid alarm-triggered policy ID.
INVALIDPARAMETERVALUE_INVALIDAUTOSCALINGPOLICYID = 'InvalidParameterValue.InvalidAutoScalingPolicyId'

# The regions specified for CLB is invalid.
INVALIDPARAMETERVALUE_INVALIDCLBREGION = 'InvalidParameterValue.InvalidClbRegion'

# Invalid filter condition.
INVALIDPARAMETERVALUE_INVALIDFILTER = 'InvalidParameterValue.InvalidFilter'

# Invalid image ID.
INVALIDPARAMETERVALUE_INVALIDIMAGEID = 'InvalidParameterValue.InvalidImageId'

# Invalid instance ID.
INVALIDPARAMETERVALUE_INVALIDINSTANCEID = 'InvalidParameterValue.InvalidInstanceId'

# Invalid instance type.
INVALIDPARAMETERVALUE_INVALIDINSTANCETYPE = 'InvalidParameterValue.InvalidInstanceType'

# Invalid launch configuration ID.
INVALIDPARAMETERVALUE_INVALIDLAUNCHCONFIGURATIONID = 'InvalidParameterValue.InvalidLaunchConfigurationId'

# Invalid lifecycle hook ID.
INVALIDPARAMETERVALUE_INVALIDLIFECYCLEHOOKID = 'InvalidParameterValue.InvalidLifecycleHookId'

# The notification group ID should be a numeric string.
INVALIDPARAMETERVALUE_INVALIDNOTIFICATIONUSERGROUPID = 'InvalidParameterValue.InvalidNotificationUserGroupId'

# Invalid scheduled action ID.
INVALIDPARAMETERVALUE_INVALIDSCHEDULEDACTIONID = 'InvalidParameterValue.InvalidScheduledActionId'

# The scheduled task name contains invalid characters.
INVALIDPARAMETERVALUE_INVALIDSCHEDULEDACTIONNAMEINCLUDEILLEGALCHAR = 'InvalidParameterValue.InvalidScheduledActionNameIncludeIllegalChar'

# Invalid subnet ID.
INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'

# The launch configuration name already exists.
INVALIDPARAMETERVALUE_LAUNCHCONFIGURATIONNAMEDUPLICATED = 'InvalidParameterValue.LaunchConfigurationNameDuplicated'

# The specified launch configuration was not found.
INVALIDPARAMETERVALUE_LAUNCHCONFIGURATIONNOTFOUND = 'InvalidParameterValue.LaunchConfigurationNotFound'

# The load balancer is in a different project.
INVALIDPARAMETERVALUE_LBPROJECTINCONSISTENT = 'InvalidParameterValue.LbProjectInconsistent'

# The lifecycle hook name already exists.
INVALIDPARAMETERVALUE_LIFECYCLEHOOKNAMEDUPLICATED = 'InvalidParameterValue.LifecycleHookNameDuplicated'

# The value exceeds the limit.
INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'

# No resource permission.
INVALIDPARAMETERVALUE_NORESOURCEPERMISSION = 'InvalidParameterValue.NoResourcePermission'

# The value should be a floating point string.
INVALIDPARAMETERVALUE_NOTSTRINGTYPEFLOAT = 'InvalidParameterValue.NotStringTypeFloat'

# The account only supports VPCs.
INVALIDPARAMETERVALUE_ONLYVPC = 'InvalidParameterValue.OnlyVpc'

# The project ID does not exist.
INVALIDPARAMETERVALUE_PROJECTIDNOTFOUND = 'InvalidParameterValue.ProjectIdNotFound'

# The value is outside the specified range.
INVALIDPARAMETERVALUE_RANGE = 'InvalidParameterValue.Range'

# The alarm policy name already exists.
INVALIDPARAMETERVALUE_SCALINGPOLICYNAMEDUPLICATE = 'InvalidParameterValue.ScalingPolicyNameDuplicate'

# The scheduled task name already exists.
INVALIDPARAMETERVALUE_SCHEDULEDACTIONNAMEDUPLICATE = 'InvalidParameterValue.ScheduledActionNameDuplicate'

# The value of maximum, minimum, or desired number of instances in the auto scaling group is invalid.
INVALIDPARAMETERVALUE_SIZE = 'InvalidParameterValue.Size'

# The start time of the scheduled task is before the current time.
INVALIDPARAMETERVALUE_STARTTIMEBEFORECURRENTTIME = 'InvalidParameterValue.StartTimeBeforeCurrentTime'

# The subnet information is invalid.
INVALIDPARAMETERVALUE_SUBNETIDS = 'InvalidParameterValue.SubnetIds'

# The backend port of the CLB layer-4 listener already exists.
INVALIDPARAMETERVALUE_TARGETPORTDUPLICATED = 'InvalidParameterValue.TargetPortDuplicated'

# The specified threshold must be within the valid range.
INVALIDPARAMETERVALUE_THRESHOLDOUTOFRANGE = 'InvalidParameterValue.ThresholdOutOfRange'

# Wrong time format.
INVALIDPARAMETERVALUE_TIMEFORMAT = 'InvalidParameterValue.TimeFormat'

# Too many values.
INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'

# The value of input parameter is too short.
INVALIDPARAMETERVALUE_TOOSHORT = 'InvalidParameterValue.TooShort'

# Incorrect UserData format.
INVALIDPARAMETERVALUE_USERDATAFORMATERROR = 'InvalidParameterValue.UserDataFormatError'

# The UserData is too long.
INVALIDPARAMETERVALUE_USERDATASIZEEXCEEDED = 'InvalidParameterValue.UserDataSizeExceeded'

# The user group does not exist.
INVALIDPARAMETERVALUE_USERGROUPIDNOTFOUND = 'InvalidParameterValue.UserGroupIdNotFound'

# The specified availability zone is not in the region.
INVALIDPARAMETERVALUE_ZONEMISMATCHREGION = 'InvalidParameterValue.ZoneMismatchRegion'

# The account does not support this operation.
INVALIDPERMISSION = 'InvalidPermission'

# The quota limit is exceeded.
LIMITEXCEEDED = 'LimitExceeded'

# Binding with the specified CLBs will make the total number of bound CLBs exceeds the upper limit.
LIMITEXCEEDED_AFTERATTACHLBLIMITEXCEEDED = 'LimitExceeded.AfterAttachLbLimitExceeded'

# The number of auto scaling groups exceeds the limit.
LIMITEXCEEDED_AUTOSCALINGGROUPLIMITEXCEEDED = 'LimitExceeded.AutoScalingGroupLimitExceeded'

# The desired number of instances exceeds the limit.
LIMITEXCEEDED_DESIREDCAPACITYLIMITEXCEEDED = 'LimitExceeded.DesiredCapacityLimitExceeded'

# Too many values for the specified filter
LIMITEXCEEDED_FILTERVALUESTOOLONG = 'LimitExceeded.FilterValuesTooLong'

# The maximum number of instances exceeds the limit.
LIMITEXCEEDED_MAXSIZELIMITEXCEEDED = 'LimitExceeded.MaxSizeLimitExceeded'

# The minimum number of instances is below the limit.
LIMITEXCEEDED_MINSIZELIMITEXCEEDED = 'LimitExceeded.MinSizeLimitExceeded'

# You are short of the quota.
LIMITEXCEEDED_QUOTANOTENOUGH = 'LimitExceeded.QuotaNotEnough'

# The number of scheduled tasks exceeds the limit.
LIMITEXCEEDED_SCHEDULEDACTIONLIMITEXCEEDED = 'LimitExceeded.ScheduledActionLimitExceeded'

# Parameter missing.
MISSINGPARAMETER = 'MissingParameter'

# A parameter is missing in a specific scenario.
MISSINGPARAMETER_INSCENARIO = 'MissingParameter.InScenario'

# The auto scaling group is performing a scaling activity.
RESOURCEINUSE_ACTIVITYINPROGRESS = 'ResourceInUse.ActivityInProgress'

# The scaling group is disabled.
RESOURCEINUSE_AUTOSCALINGGROUPNOTACTIVE = 'ResourceInUse.AutoScalingGroupNotActive'

# There are still normal instances in the auto scaling group.
RESOURCEINUSE_INSTANCEINGROUP = 'ResourceInUse.InstanceInGroup'

# The specified launch configuration is still used in the scaling group.
RESOURCEINUSE_LAUNCHCONFIGURATIONIDINUSE = 'ResourceInUse.LaunchConfigurationIdInUse'

# The maximum number of instances in the auto scaling group is exceeded.
RESOURCEINSUFFICIENT_AUTOSCALINGGROUPABOVEMAXSIZE = 'ResourceInsufficient.AutoScalingGroupAboveMaxSize'

# The number of instances in the auto scaling group is below the minimum value.
RESOURCEINSUFFICIENT_AUTOSCALINGGROUPBELOWMINSIZE = 'ResourceInsufficient.AutoScalingGroupBelowMinSize'

# The number of instances in a scaling group is more than the maximum capacity.
RESOURCEINSUFFICIENT_INSERVICEINSTANCEABOVEMAXSIZE = 'ResourceInsufficient.InServiceInstanceAboveMaxSize'

# The number of instances in a scaling group is less than the minimum capacity.
RESOURCEINSUFFICIENT_INSERVICEINSTANCEBELOWMINSIZE = 'ResourceInsufficient.InServiceInstanceBelowMinSize'

# The scaling group does not exist.
RESOURCENOTFOUND_AUTOSCALINGGROUPNOTFOUND = 'ResourceNotFound.AutoScalingGroupNotFound'

# The notification does not exist.
RESOURCENOTFOUND_AUTOSCALINGNOTIFICATIONNOTFOUND = 'ResourceNotFound.AutoScalingNotificationNotFound'

# The specified CMQ queue does not exist.
RESOURCENOTFOUND_CMQQUEUENOTFOUND = 'ResourceNotFound.CmqQueueNotFound'

# The specified instance does not exist.
RESOURCENOTFOUND_INSTANCESNOTFOUND = 'ResourceNotFound.InstancesNotFound'

# The target instance is not in the auto scaling group.
RESOURCENOTFOUND_INSTANCESNOTINAUTOSCALINGGROUP = 'ResourceNotFound.InstancesNotInAutoScalingGroup'

# The specified launch configuration does not exist.
RESOURCENOTFOUND_LAUNCHCONFIGURATIONIDNOTFOUND = 'ResourceNotFound.LaunchConfigurationIdNotFound'

# The instance corresponding to the lifecycle hook does not exist.
RESOURCENOTFOUND_LIFECYCLEHOOKINSTANCENOTFOUND = 'ResourceNotFound.LifecycleHookInstanceNotFound'

# The specified lifecycle hook was not found.
RESOURCENOTFOUND_LIFECYCLEHOOKNOTFOUND = 'ResourceNotFound.LifecycleHookNotFound'

# The specified listener does not exist.
RESOURCENOTFOUND_LISTENERNOTFOUND = 'ResourceNotFound.ListenerNotFound'

# The specified load balancer was not found.
RESOURCENOTFOUND_LOADBALANCERNOTFOUND = 'ResourceNotFound.LoadBalancerNotFound'

# The specified CLB does not exist in the current scaling group.
RESOURCENOTFOUND_LOADBALANCERNOTINAUTOSCALINGGROUP = 'ResourceNotFound.LoadBalancerNotInAutoScalingGroup'

# The specified location does not exist.
RESOURCENOTFOUND_LOCATIONNOTFOUND = 'ResourceNotFound.LocationNotFound'

# The alarm policy does not exist.
RESOURCENOTFOUND_SCALINGPOLICYNOTFOUND = 'ResourceNotFound.ScalingPolicyNotFound'

# The specified scheduled task does not exist.
RESOURCENOTFOUND_SCHEDULEDACTIONNOTFOUND = 'ResourceNotFound.ScheduledActionNotFound'

# The TDMQ-CMQ queue doesn't exist.
RESOURCENOTFOUND_TDMQCMQQUEUENOTFOUND = 'ResourceNotFound.TDMQCMQQueueNotFound'

# The TDMQ-CMQ topic doesn't exist.
RESOURCENOTFOUND_TDMQCMQTOPICNOTFOUND = 'ResourceNotFound.TDMQCMQTopicNotFound'

# The auto scaling group is exceptional.
RESOURCEUNAVAILABLE_AUTOSCALINGGROUPABNORMALSTATUS = 'ResourceUnavailable.AutoScalingGroupAbnormalStatus'

# The auto scaling group is disabled.
RESOURCEUNAVAILABLE_AUTOSCALINGGROUPDISABLED = 'ResourceUnavailable.AutoScalingGroupDisabled'

# The auto scaling group is active.
RESOURCEUNAVAILABLE_AUTOSCALINGGROUPINACTIVITY = 'ResourceUnavailable.AutoScalingGroupInActivity'

# There are no subscribers for the specified CMQ topic.
RESOURCEUNAVAILABLE_CMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.CmqTopicHasNoSubscriber'

# The instance and the auto scaling group are in different VPCs.
RESOURCEUNAVAILABLE_CVMVPCINCONSISTENT = 'ResourceUnavailable.CvmVpcInconsistent'

# The specified instance is active.
RESOURCEUNAVAILABLE_INSTANCEINOPERATION = 'ResourceUnavailable.InstanceInOperation'

# The instance does not support **No Charges When Shut Down**.
RESOURCEUNAVAILABLE_INSTANCENOTSUPPORTSTOPCHARGING = 'ResourceUnavailable.InstanceNotSupportStopCharging'

# The instance already exists in the auto scaling group.
RESOURCEUNAVAILABLE_INSTANCESALREADYINAUTOSCALINGGROUP = 'ResourceUnavailable.InstancesAlreadyInAutoScalingGroup'

# The launch configuration is exceptional.
RESOURCEUNAVAILABLE_LAUNCHCONFIGURATIONSTATUSABNORMAL = 'ResourceUnavailable.LaunchConfigurationStatusAbnormal'

# The backend region of the CLB is not the same as the one for AS service.
RESOURCEUNAVAILABLE_LBBACKENDREGIONINCONSISTENT = 'ResourceUnavailable.LbBackendRegionInconsistent'

# The CLBs are not in the same project.
RESOURCEUNAVAILABLE_LBPROJECTINCONSISTENT = 'ResourceUnavailable.LbProjectInconsistent'

# The CLB and scaling group should reside in the same VPC.
RESOURCEUNAVAILABLE_LBVPCINCONSISTENT = 'ResourceUnavailable.LbVpcInconsistent'

# The lifecycle action has already been set.
RESOURCEUNAVAILABLE_LIFECYCLEACTIONRESULTHASSET = 'ResourceUnavailable.LifecycleActionResultHasSet'

# CLB is active in the scaling group.
RESOURCEUNAVAILABLE_LOADBALANCERINOPERATION = 'ResourceUnavailable.LoadBalancerInOperation'

# Project inconsistency.
RESOURCEUNAVAILABLE_PROJECTINCONSISTENT = 'ResourceUnavailable.ProjectInconsistent'

# Unable to add instances to the scaling group when they are shut down.
RESOURCEUNAVAILABLE_STOPPEDINSTANCENOTALLOWATTACH = 'ResourceUnavailable.StoppedInstanceNotAllowAttach'

# The TDMQ-CMQ topic is not subscribed.
RESOURCEUNAVAILABLE_TDMQCMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.TDMQCMQTopicHasNoSubscriber'

# The specified availability zone is unavailable.
RESOURCEUNAVAILABLE_ZONEUNAVAILABLE = 'ResourceUnavailable.ZoneUnavailable'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM signature/authentication error.
AUTHFAILURE = 'AuthFailure'

# The sub-account has no permissions.
AUTHFAILURE_SUBACCOUNTDENIED = 'AuthFailure.SubAccountDenied'

# Backend or process error.
CDBERROR = 'CdbError'

# Backup error.
CDBERROR_BACKUPERROR = 'CdbError.BackupError'

# Backend database error.
CDBERROR_DATABASEERROR = 'CdbError.DatabaseError'

# Import task error.
CDBERROR_IMPORTERROR = 'CdbError.ImportError'

# Backend task error.
CDBERROR_TASKERROR = 'CdbError.TaskError'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Async task exception.
FAILEDOPERATION_ASYNCTASKSTATUSERROR = 'FailedOperation.AsyncTaskStatusError'

# Failed to lock the instance while performing exclusive operations. Please try again later.
FAILEDOPERATION_CDBINSTANCELOCKFAILERROR = 'FailedOperation.CdbInstanceLockFailError'

# Creation failed. Please check whether the user already exists.
FAILEDOPERATION_CREATEACCOUNTERROR = 'FailedOperation.CreateAccountError'

# Failed to create the audit rule.
FAILEDOPERATION_CREATEAUDITFAILERROR = 'FailedOperation.CreateAuditFailError'

# Failed to assign an exclusive VIP to the read-only replica.
FAILEDOPERATION_CREATEROVIPERROR = 'FailedOperation.CreateRoVipError'

# Failed to query database proxy.
FAILEDOPERATION_DESCRIBEPROXYGROUPERROR = 'FailedOperation.DescribeProxyGroupError'

# An error occurred while obtaining permissions.
FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'

# Failed to deserialize JSON.
FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'

# It is not a read-only instance with delayed replication enabled.
FAILEDOPERATION_NOTDELAYRO = 'FailedOperation.NotDelayRo'

# The executed operation to modify permissions is invalid. You can refer to product documentation for more information about permissions that can be modified for this instance. If you have any questions, please contact customer service.
FAILEDOPERATION_PRIVILEGEDATAILLEGAL = 'FailedOperation.PrivilegeDataIllegal'

# Database proxy in an exceptional status.
FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'

# Log query failed.
FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'

# The proxy is being created or already exists. You cannot create it again.
FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError'

# Exception with the backend request for the service. Please contact customer service.
FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'

# Failed to initiate the operation. Please try again later. If the operation remains unsuccessful, please contact customer service.
FAILEDOPERATION_STARTFLOWERROR = 'FailedOperation.StartFlowError'

# Task status conflict.
FAILEDOPERATION_STATUSCONFLICT = 'FailedOperation.StatusConflict'

# Failed to submit the task. Please try again later. If the submission remains unsuccessful, please contact customer service.
FAILEDOPERATION_SUBMITASYNCTASKERROR = 'FailedOperation.SubmitAsyncTaskError'

# The query timed out.
FAILEDOPERATION_TIMEOUTERROR = 'FailedOperation.TimeoutError'

# This type of operations cannot be performed.
FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'

# An internal error occurred.
INTERNALERROR = 'InternalError'

# An error occurred while querying async tasks.
INTERNALERROR_ASYNCREQUESTERROR = 'InternalError.AsyncRequestError'

# An error occurred in the internal service of the audit service.
INTERNALERROR_AUDITERROR = 'InternalError.AuditError'

# Internal exception of the audit service.
INTERNALERROR_AUDITOSSLOGICERROR = 'InternalError.AuditOssLogicError'

# Authentication failed.
INTERNALERROR_AUTHERROR = 'InternalError.AuthError'

# Authentication failed.
INTERNALERROR_CAUTHERROR = 'InternalError.CauthError'

# Internal system error.
INTERNALERROR_CDBCGWERROR = 'InternalError.CdbCgwError'

# System error.
INTERNALERROR_CDBERROR = 'InternalError.CdbError'

# Failed to obtain file information.
INTERNALERROR_COSERROR = 'InternalError.CosError'

# Database exception
INTERNALERROR_DBERROR = 'InternalError.DBError'

# Database operation failed.
INTERNALERROR_DBOPERATIONERROR = 'InternalError.DBOperationError'

# The database record does not exist.
INTERNALERROR_DBRECORDNOTEXISTERROR = 'InternalError.DBRecordNotExistError'

# Internal database error.
INTERNALERROR_DATABASEACCESSERROR = 'InternalError.DatabaseAccessError'

# Internal system error.
INTERNALERROR_DESERROR = 'InternalError.DesError'

# Security group operation error.
INTERNALERROR_DFWERROR = 'InternalError.DfwError'

# SQL statement error
INTERNALERROR_EXESQLERROR = 'InternalError.ExeSqlError'

# 
INTERNALERROR_EXECUTESQLERROR = 'InternalError.ExecuteSQLError'

# File transfer exception
INTERNALERROR_FTPERROR = 'InternalError.FtpError'

# Exceptional HTTP request
INTERNALERROR_HTTPERROR = 'InternalError.HttpError'

# Internal service error
INTERNALERROR_INNERCOMMONERROR = 'InternalError.InnerCommonError'

# Internal service error. Please contact customer service.
INTERNALERROR_INTERNALASSERTERROR = 'InternalError.InternalAssertError'

# An exception occurred while executing the request.
INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'

# The backend failed to request the service. Please contact customer service.
INTERNALERROR_INTERNALREQUESTERROR = 'InternalError.InternalRequestError'

# An error occurred while accessing internal service.
INTERNALERROR_INTERNALSERVICEERRORERR = 'InternalError.InternalServiceErrorErr'

# Failed to parse JSON.
INTERNALERROR_JSONERROR = 'InternalError.JSONError'

# Network error
INTERNALERROR_NETWORKERROR = 'InternalError.NetworkError'

# An error occurred in TencentDB for MySQL High-Availability Edition database service.
INTERNALERROR_OSSERROR = 'InternalError.OssError'

# Parameter error
INTERNALERROR_PARAMERROR = 'InternalError.ParamError'

# Regular expression compilation error.
INTERNALERROR_REGEXPCOMPILEERROR = 'InternalError.RegexpCompileError'

# The resource does not match.
INTERNALERROR_RESOURCENOTMATCH = 'InternalError.ResourceNotMatch'

# The resource is not unique.
INTERNALERROR_RESOURCENOTUNIQUE = 'InternalError.ResourceNotUnique'

# Security group error
INTERNALERROR_SECURITYGROUPERROR = 'InternalError.SecurityGroupError'

# Internal error of the system.
INTERNALERROR_SERVERERROR = 'InternalError.ServerError'

# An exception occurred in the internal service.
INTERNALERROR_SERVICEERROR = 'InternalError.ServiceError'

# Failed to modify the tag. Please try again later.
INTERNALERROR_TAGERROR = 'InternalError.TagError'

# Task exception
INTERNALERROR_TASKERROR = 'InternalError.TaskError'

# Async task error.
INTERNALERROR_TASKFRAMEERROR = 'InternalError.TaskFrameError'

# Time window error
INTERNALERROR_TIMEWINDOWERROR = 'InternalError.TimeWindowError'

# Transaction system error.
INTERNALERROR_TRADEERROR = 'InternalError.TradeError'

# Operation failed
INTERNALERROR_TRANSACTIONBEGINERROR = 'InternalError.TransactionBeginError'

# Unknown error
INTERNALERROR_UNDEFINEDERROR = 'InternalError.UndefinedError'

# Unknown error
INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'

# VPC or subnet error.
INTERNALERROR_VPCERROR = 'InternalError.VpcError'

# Parameter error.
INVALIDPARAMETER = 'InvalidParameter'

# This API was not found.
INVALIDPARAMETER_CONTROLLERNOTFOUNDERROR = 'InvalidParameter.ControllerNotFoundError'

# Parameter exception.
INVALIDPARAMETER_EXCEPTIONPARAM = 'InvalidParameter.ExceptionParam'

# The instance is not found.
INVALIDPARAMETER_INSTANCENAMENOTFOUND = 'InvalidParameter.InstanceNameNotFound'

# The instance does not exist.
INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'

# The async task does not exist.
INVALIDPARAMETER_INVALIDASYNCREQUESTID = 'InvalidParameter.InvalidAsyncRequestId'

# Invalid name.
INVALIDPARAMETER_INVALIDNAME = 'InvalidParameter.InvalidName'

# Invalid parameter value
INVALIDPARAMETER_INVALIDPARAMETERERROR = 'InvalidParameter.InvalidParameterError'

# Failed to deserialize JSON.
INVALIDPARAMETER_JSONUNMARSHALERROR = 'InvalidParameter.JsonUnmarshalError'

# The resource already exists.
INVALIDPARAMETER_RESOURCEEXISTS = 'InvalidParameter.ResourceExists'

# The resource does not exist.
INVALIDPARAMETER_RESOURCENOTEXISTS = 'InvalidParameter.ResourceNotExists'

# The resource is not found.
INVALIDPARAMETER_RESOURCENOTFOUND = 'InvalidParameter.ResourceNotFound'

# The account description contains special characters.
INVALIDPARAMETERVALUE_ACCOUNTDESCRIPTIONCHARACTERERROR = 'InvalidParameterValue.AccountDescriptionCharacterError'

# The account description should not exceed 255 characters.
INVALIDPARAMETERVALUE_ACCOUNTDESCRIPTIONLENGTHERROR = 'InvalidParameterValue.AccountDescriptionLengthError'

# Incorrect format of the `host` parameter in the account.
INVALIDPARAMETERVALUE_ACCOUNTHOSTRULEERROR = 'InvalidParameterValue.AccountHostRuleError'

# The account password contains invalid characters.
INVALIDPARAMETERVALUE_ACCOUNTPASSWORDCHARACTERERROR = 'InvalidParameterValue.AccountPasswordCharacterError'

# The account password is too long or too short.
INVALIDPARAMETERVALUE_ACCOUNTPASSWORDLENGTHERROR = 'InvalidParameterValue.AccountPasswordLengthError'

# The password format is incorrect. It should contain 8 to 64 characters and must contain at least two character sets of the following: letters, digits, and special symbols (_+-&=!@#$%^*()).
INVALIDPARAMETERVALUE_ACCOUNTPASSWORDRULEERROR = 'InvalidParameterValue.AccountPasswordRuleError'

# Data conversion failed.
INVALIDPARAMETERVALUE_DATACONVERTERROR = 'InvalidParameterValue.DataConvertError'

# Invalid parameter value
INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.InvalidParameterValueError'

# Incorrect format of the account username.
INVALIDPARAMETERVALUE_USERNAMERULEERROR = 'InvalidParameterValue.UserNameRuleError'

# The account does not exist.
INVALIDPARAMETERVALUE_USERNOTEXISTERROR = 'InvalidParameterValue.UserNotExistError'

# No root account found.
INVALIDPARAMETERVALUE_VERIFYACCOUNTNOROOTERROR = 'InvalidParameterValue.VerifyAccountNoRootError'

# Invalid account password.
INVALIDPARAMETERVALUE_VERIFYACCOUNTPASSWORDERROR = 'InvalidParameterValue.VerifyAccountPasswordError'

# The account does not have the GRANT permission.
INVALIDPARAMETERVALUE_VERIFYACCOUNTPRIVERROR = 'InvalidParameterValue.VerifyAccountPrivError'

# The quota limit has been reached.
LIMITEXCEEDED = 'LimitExceeded'

# Missing parameter
MISSINGPARAMETER = 'MissingParameter'

# Account-related parameters are missing.
MISSINGPARAMETER_ACCOUNTMISSINGPARAMETERERROR = 'MissingParameter.AccountMissingParameterError'

# Required parameters are missing.
MISSINGPARAMETER_MISSINGPARAMERROR = 'MissingParameter.MissingParamError'

# Operation denied.
OPERATIONDENIED = 'OperationDenied'

# The instance is performing another task.
OPERATIONDENIED_ACTIONINPROCESS = 'OperationDenied.ActionInProcess'

# Unsupported operation.
OPERATIONDENIED_ACTIONNOTSUPPORT = 'OperationDenied.ActionNotSupport'

# The audit policies conflict.
OPERATIONDENIED_AUDITPOLICYCONFLICTERROR = 'OperationDenied.AuditPolicyConflictError'

# The audit policy already exists.
OPERATIONDENIED_AUDITPOLICYEXISTERROR = 'OperationDenied.AuditPolicyExistError'

# The number of audit policies exceeds the limit.
OPERATIONDENIED_AUDITPOLICYOVERQUOTAERROR = 'OperationDenied.AuditPolicyOverQuotaError'

# The audit rule has been associated.
OPERATIONDENIED_AUDITRULEHASBIND = 'OperationDenied.AuditRuleHasBind'

# The audit rule does not exist.
OPERATIONDENIED_AUDITRULENOTEXISTERROR = 'OperationDenied.AuditRuleNotExistError'

# Exceptional audit status.
OPERATIONDENIED_AUDITSTATUSERROR = 'OperationDenied.AuditStatusError'

# The audit tasks conflict.
OPERATIONDENIED_AUDITTASKCONFLICTERROR = 'OperationDenied.AuditTaskConflictError'

# The operation is not allowed as the RO group contains an invalid read-only instance.
OPERATIONDENIED_CONFLICTROSTATUS = 'OperationDenied.ConflictRoStatus'

# The configuration of read-only group is being modified. Please do not make repeated requests.
OPERATIONDENIED_CONFLICTSTATUS = 'OperationDenied.ConflictStatus'

# You have enabled the compliance audit feature of DBbrain, so you cannot enable the rule-based audit.
OPERATIONDENIED_DBBRAINPOLICYCONFLICT = 'OperationDenied.DBBrainPolicyConflict'

# The operation is not allowed during the delayed replication.
OPERATIONDENIED_DELAYREPLICATIONRUNNING = 'OperationDenied.DelayReplicationRunning'

# The root account cannot be deleted.
OPERATIONDENIED_DELETEROOTACCOUNTERROR = 'OperationDenied.DeleteRootAccountError'

# This instance needs permissions to use this feature.
OPERATIONDENIED_FUNCTIONDENIED = 'OperationDenied.FunctionDenied'

# 
OPERATIONDENIED_INSTTYPENOTSUPPORT = 'OperationDenied.InstTypeNotSupport'

# Instance locks are in conflict. Please try again later.
OPERATIONDENIED_INSTANCELOCKERCONFLICT = 'OperationDenied.InstanceLockerConflict'

# Exceptional instance status
OPERATIONDENIED_INSTANCESTATUSERROR = 'OperationDenied.InstanceStatusError'

# Delayed replication is not allowed because the instance is executing another task.
OPERATIONDENIED_INSTANCETASKRUNNING = 'OperationDenied.InstanceTaskRunning'

# The instance does not support this operation.
OPERATIONDENIED_INSTANCEUNSUPPORTEDOPERATEERROR = 'OperationDenied.InstanceUnsupportedOperateError'

# Basic instances do not support this operation (feature).
OPERATIONDENIED_NOTSUPPORTBASIC = 'OperationDenied.NotSupportBasic'

# The host information of the local root account cannot be modified.
OPERATIONDENIED_NOTSUPPORTMODIFYLOCALROOTHOSTERROR = 'OperationDenied.NotSupportModifyLocalRootHostError'

# There are other orders being submitted. Please try again later.
OPERATIONDENIED_OTHERODERINPROCESS = 'OperationDenied.OtherOderInProcess'

# This operation is not allowed during database proxy upgrade task.
OPERATIONDENIED_PROXYUPGRADETASKSTATUSERROR = 'OperationDenied.ProxyUpgradeTaskStatusError'

# The maximum number of results has been reached. Please narrow down your query.
OPERATIONDENIED_RESULTOVERLIMIT = 'OperationDenied.ResultOverLimit'

# The Tencent Cloud sub-account is not allowed to perform the operation due to insufficient permissions.
OPERATIONDENIED_SUBACCOUNTOPERATIONDENIED = 'OperationDenied.SubAccountOperationDenied'

# This instance is not refundable.
OPERATIONDENIED_UNSUPPORTREFUNDERROR = 'OperationDenied.UnSupportRefundError'

# The audit feature cannot be enabled.
OPERATIONDENIED_UNSUPPORTOPENAUDITERROR = 'OperationDenied.UnsupportOpenAuditError'

# This account is not authorized to access the requested resource.
OPERATIONDENIED_USERHASNOSTRATEGY = 'OperationDenied.UserHasNoStrategy'

# Incorrect password or verification failed.
OPERATIONDENIED_WRONGPASSWORD = 'OperationDenied.WrongPassword'

# The backend task status is invalid.
OPERATIONDENIED_WRONGSTATUS = 'OperationDenied.WrongStatus'

# Limit exceeded.
OVERQUOTA = 'OverQuota'

# The resource is occupied.
RESOURCEINUSE = 'ResourceInUse'

# Insufficient resource.
RESOURCEINSUFFICIENT = 'ResourceInsufficient'

# The resource does not exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# The instance cannot be found. Please check whether your instance status is normal.
RESOURCENOTFOUND_CDBINSTANCENOTFOUNDERROR = 'ResourceNotFound.CdbInstanceNotFoundError'

# The instance does not exist.
RESOURCENOTFOUND_INSTANCENOTFUNDERROR = 'ResourceNotFound.InstanceNotFundError'

# The resource is unavailable.
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# Verification failed. Insufficient permissions.
UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPrivileges'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# Unsupported permission.
UNSUPPORTEDOPERATION_PRIVILEGESUNSUPPORTEDERROR = 'UnsupportedOperation.PrivilegesUnsupportedError'
